@@ -1,19 +1,6 @@
-// Copyright (C) 2003 Dolphin Project.
-
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, version 2.0.
-
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License 2.0 for more details.
-
-// A copy of the GPL 2.0 should have been included with the program.
-// If not, see http://www.gnu.org/licenses/
-
-// Official SVN repository and contact information can be found at
-// http://code.google.com/p/dolphin-emu/
+// Copyright 2009 Dolphin Emulator Project
+// Licensed under GPLv2+
+// Refer to the license.txt file included.
 
 #include <gccore.h>
 #include <ogcsys.h>
@@ -41,7 +28,7 @@ void RealDSP::Init()
 
 	u32 level;
 	_CPU_ISR_Disable(level);
-	IRQ_Request(IRQ_DSP_DSP, dsp_irq_handler, NULL);
+	IRQ_Request(IRQ_DSP_DSP, dsp_irq_handler, nullptr);
 	_CPU_ISR_Restore(level);
 }
 
